@@ -5,6 +5,7 @@ pub struct Config {
     pub persistence: Persistence,
     pub transmission: Transmission,
     pub rss_list: Vec<RssList>,
+    pub notification: Notification,
 }
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct Persistence {
@@ -25,3 +26,13 @@ pub struct RssList {
     pub filters: Vec<String>,
     pub download_dir: String,
 }
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct Notification {
+    pub telegram: Option<TelegramNotification>
+}
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct TelegramNotification {
+    pub bot_token: String,
+    pub chat_id: i64,
+}
\ No newline at end of file
